"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const crypto = require("crypto");
const util_1 = require("util");
const dsa_digest_js_1 = require("./dsa_digest.js");
const hmac_digest_js_1 = require("./hmac_digest.js");
const node_key_js_1 = require("./node_key.js");
const secret_key_js_1 = require("./secret_key.js");
const webcrypto_js_1 = require("./webcrypto.js");
let oneShotSign = crypto.sign;
if (oneShotSign.length > 3) {
    oneShotSign = util_1.promisify(oneShotSign);
}
const sign = async (alg, key, data) => {
    let keyObject;
    if (key instanceof Uint8Array) {
        if (!alg.startsWith('HS')) {
            throw new TypeError('symmetric keys are only applicable for HMAC-based JWA algorithms');
        }
        keyObject = secret_key_js_1.default(key);
    }
    else if (webcrypto_js_1.isCryptoKey(key)) {
        keyObject = webcrypto_js_1.getKeyObject(key);
    }
    else {
        keyObject = key;
    }
    if (alg.startsWith('HS')) {
        const bitlen = parseInt(alg.substr(-3), 10);
        if (!keyObject.symmetricKeySize || keyObject.symmetricKeySize << 3 < bitlen) {
            throw new TypeError(`${alg} requires symmetric keys to be ${bitlen} bits or larger`);
        }
        const hmac = crypto.createHmac(hmac_digest_js_1.default(alg), keyObject);
        hmac.update(data);
        return hmac.digest();
    }
    return oneShotSign(dsa_digest_js_1.default(alg), data, node_key_js_1.default(alg, keyObject));
};
exports.default = sign;
