"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const crypto = require("crypto");
const util_1 = require("util");
const dsa_digest_js_1 = require("./dsa_digest.js");
const node_key_js_1 = require("./node_key.js");
const sign_js_1 = require("./sign.js");
const webcrypto_js_1 = require("./webcrypto.js");
let oneShotVerify = crypto.verify;
if (oneShotVerify.length > 4) {
    oneShotVerify = util_1.promisify(oneShotVerify);
}
const verify = async (alg, key, signature, data) => {
    if (alg.startsWith('HS')) {
        const expected = await sign_js_1.default(alg, key, data);
        const actual = signature;
        try {
            return crypto.timingSafeEqual(actual, expected);
        }
        catch {
            return false;
        }
    }
    const algorithm = dsa_digest_js_1.default(alg);
    if (webcrypto_js_1.isCryptoKey(key)) {
        key = webcrypto_js_1.getKeyObject(key);
    }
    else if (!(key instanceof crypto.KeyObject)) {
        throw new TypeError('invalid key object type provided');
    }
    const keyInput = node_key_js_1.default(alg, key);
    try {
        return oneShotVerify(algorithm, data, keyInput, signature);
    }
    catch {
        return false;
    }
};
exports.default = verify;
